==> theia-0.1.1-py3-none-any.whl: theia/aws/security/iam.py <==
import pulumi

from pulumi_aws import iam

from pydantic.dataclasses import dataclass
from typing import Optional, Mapping, Literal, List

from theia import ResourceOptions
from theia.registry import StackRegistry
from theia.utils.logger import Logger
from theia.definitions import THEIA_VERSION


logger = Logger("iam")


@dataclass
class InlinePolicy:
    name: str
    policy: str


@dataclass
class RoleResult:
    arn: str
    assume_role_policy: str
    permissions_boundary: str


class User:
    def __new__(
        cls,
        resource_name: str,
        policy: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> iam.User:
        cls.resource_name = resource_name
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}

        logger.info(f"creating resource iam user {resource_name}")
        user = iam.User(resource_name, name=resource_name, tags=merged_tags, opts=opts)

        export_values = {"id": user.id, "arn": user.arn, "unique_id": user.unique_id}

        if policy:
            logger.info(f"creating policy and attaching it to user {resource_name}")
            user_policy = iam.UserPolicy(
                f"{resource_name}-policy",
                name=f"{resource_name}-policy",
                user=user.name,
                policy=policy,
                opts=ResourceOptions(parent=user, depends_on=[user]),
            )
            export_values["policy_id"] = user_policy.id

        pulumi.export(f"user---{resource_name}", export_values)
        return user

    @staticmethod
    def get_access_key(
        resource_name: str,
        user: str,
        pgp_key: Optional[str] = None,
        status: Optional[Literal["Active", "Inactive"]] = "Active",
        opts: Optional[ResourceOptions] = None,
    ) -> iam.AccessKey:
        logger.info(f"fetching access key for user {resource_name}")
        access_key = iam.AccessKey(
            resource_name, user=user, pgp_key=pgp_key, status=status, opts=opts
        )
        export_values = {
            "id": access_key.id,
            "created": access_key.create_date,
        }
        if pgp_key:
            export_values["encrypted_secret"] = access_key.encrypted_secret

        pulumi.export(f"access_key---{resource_name}", export_values)
        return access_key

    @staticmethod
    def import_(stack: str, resource_name: str) -> iam.User:
        stack_ref = StackRegistry.get(stack_name=stack)
        user = stack_ref.get_output(name=f"user---{resource_name}")
        return iam.User.get(resource_name=resource_name, id=user["id"])


class Role:
    def __new__(
        cls,
        resource_name: str,
        assume_role_policy: str,
        description: Optional[str] = None,
        managed_policy_arns: Optional[List[str]] = None,
        role_policy: Optional[str] = None,
        inline_policies: Optional[List[InlinePolicy]] = None,
        max_session_duration_seconds: Optional[int] = 3600,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> iam.Role:
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}

        if inline_policies:
            inline_policy_args = [
                iam.RoleInlinePolicyArgs(name=policy.name, policy=policy.policy)
                for policy in inline_policies
            ]

        logger.info(f"creating resource iam role {resource_name}")
        role = iam.Role(
            resource_name,
            name=resource_name,
            assume_role_policy=assume_role_policy,
            description=description,
            managed_policy_arns=managed_policy_arns,
            inline_policies=None if not inline_policies else inline_policy_args,
            max_session_duration=max_session_duration_seconds,
            tags=merged_tags,
            opts=opts,
        )

        export_values = {
            "id": role.id,
            "arn": role.arn,
            "created": role.create_date,
            "unique_id": role.unique_id,
        }

        if role_policy:
            logger.info(f"creating policy and attaching it to role {resource_name}")
            role_policy_resource = iam.RolePolicy(
                f"{resource_name}-policy",
                name=f"{resource_name}-policy",
                role=role.name,
                policy=role_policy,
                opts=ResourceOptions(parent=role, depends_on=[role]),
            )
            export_values["policy_id"] = role_policy_resource.id

        pulumi.export(f"role---{resource_name}", export_values)
        return role

    @staticmethod
    def fetch(name: str) -> RoleResult:
        try:
            role = iam.get_role(name=name)
        except Exception:
            logger.critical("role with name %s not found", name)
            raise Exception(f"role with name {name} not found")

        role_result = RoleResult(
            role.arn, role.assume_role_policy, role.permissions_boundary
        )

        return role_result

    @staticmethod
    def import_(stack: str, resource_name: str) -> iam.Role:
        stack_ref = StackRegistry.get(stack_name=stack)
        role = stack_ref.get_output(name=f"role---{resource_name}")
        return iam.Role.get(resource_name=resource_name, id=role["id"])


class Policy:
    def __new__(
        cls,
        resource_name: str,
        policy: str,
        description: Optional[str] = None,
        path: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> iam.Policy:
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}

        logger.info(f"creating resource iam policy {resource_name}")
        policy_resource = iam.Policy(
            resource_name,
            name=resource_name,
            policy=policy,
            description=description,
            path=path,
            tags=merged_tags,
            opts=opts,
        )

        pulumi.export(
            f"policy---{resource_name}",
            {"arn": policy_resource.arn, "policy-id": policy_resource.policy_id},
        )

        return policy

    @staticmethod
    def import_(stack: str, resource_name: str) -> iam.Policy:
        stack_ref = StackRegistry.get(stack_name=stack)
        policy = stack_ref.get_output(name=f"policy---{resource_name}")
        return iam.User.get(resource_name=resource_name, id=policy["id"])

==> theia-0.1.2-py3-none-any.whl: theia/aws/security/iam.py <==
import pulumi

from pulumi_aws import iam

from pydantic.dataclasses import dataclass
from typing import Optional, Mapping, Literal, List

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia.definitions import THEIA_VERSION
from theia.registry import StackRegistry, GlobalTags


logger = Logger("iam")


@dataclass
class InlinePolicy:
    name: str
    policy: str


@dataclass
class RoleResult:
    arn: str
    assume_role_policy: str
    permissions_boundary: str


class User:
    def __new__(
        cls,
        resource_name: str,
        policy: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> iam.User:
        cls.resource_name = resource_name
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}

        user = iam.User(resource_name, name=resource_name, tags=merged_tags, opts=opts)

        export_values = {"id": user.id, "arn": user.arn, "unique_id": user.unique_id}

        if policy:
            user_policy = iam.UserPolicy(
                f"{resource_name}-policy",
                name=f"{resource_name}-policy",
                user=user.name,
                policy=policy,
                opts=ResourceOptions(parent=user, depends_on=[user]),
            )
            export_values["policy_id"] = user_policy.id

        pulumi.export(f"user---{resource_name}", export_values)
        return user

    @staticmethod
    def get_access_key(
        resource_name: str,
        user: str,
        pgp_key: Optional[str] = None,
        status: Optional[Literal["Active", "Inactive"]] = "Active",
        opts: Optional[ResourceOptions] = None,
    ) -> iam.AccessKey:
        access_key = iam.AccessKey(
            resource_name, user=user, pgp_key=pgp_key, status=status, opts=opts
        )
        export_values = {
            "id": access_key.id,
            "created": access_key.create_date,
        }
        if pgp_key:
            export_values["encrypted_secret"] = access_key.encrypted_secret

        pulumi.export(f"access_key---{resource_name}", export_values)
        return access_key

    @staticmethod
    def import_(stack: str, resource_name: str) -> iam.User:
        stack_ref = StackRegistry.get(stack_name=stack)
        user = stack_ref.get_output(name=f"user---{resource_name}")
        return iam.User.get(resource_name=resource_name, id=user["id"])


class Role:
    def __new__(
        cls,
        resource_name: str,
        assume_role_policy: str,
        description: Optional[str] = None,
        managed_policy_arns: Optional[List[str]] = None,
        role_policy: Optional[str] = None,
        inline_policies: Optional[List[InlinePolicy]] = None,
        max_session_duration_seconds: Optional[int] = 3600,
        force_detach_policies: Optional[bool] = False,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> iam.Role:
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}

        if inline_policies:
            inline_policy_args = [
                iam.RoleInlinePolicyArgs(name=policy.name, policy=policy.policy)
                for policy in inline_policies
            ]

        role = iam.Role(
            resource_name,
            name=resource_name,
            assume_role_policy=assume_role_policy,
            description=description,
            managed_policy_arns=managed_policy_arns,
            inline_policies=None if not inline_policies else inline_policy_args,
            max_session_duration=max_session_duration_seconds,
            force_detach_policies=force_detach_policies,
            tags=merged_tags,
            opts=opts,
        )

        export_values = {
            "id": role.id,
            "arn": role.arn,
            "created": role.create_date,
            "unique_id": role.unique_id,
        }

        if role_policy:
            role_policy_resource = iam.RolePolicy(
                f"{resource_name}-policy",
                name=f"{resource_name}-policy",
                role=role.name,
                policy=role_policy,
                opts=ResourceOptions(parent=role, depends_on=[role]),
            )
            export_values["policy_id"] = role_policy_resource.id

        pulumi.export(f"role---{resource_name}", export_values)
        return role

    @staticmethod
    def fetch(name: str) -> RoleResult:
        try:
            role = iam.get_role(name=name)
        except Exception:
            logger.critical("role with name %s not found", name)
            raise Exception(f"role with name {name} not found")

        role_result = RoleResult(
            role.arn, role.assume_role_policy, role.permissions_boundary
        )

        return role_result

    @staticmethod
    def import_(stack: str, resource_name: str) -> iam.Role:
        stack_ref = StackRegistry.get(stack_name=stack)
        role = stack_ref.get_output(name=f"role---{resource_name}")
        return iam.Role.get(resource_name=resource_name, id=role["id"])


class Policy:
    def __new__(
        cls,
        resource_name: str,
        policy: str,
        description: Optional[str] = None,
        path: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> iam.Policy:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        policy_resource = iam.Policy(
            resource_name,
            name=resource_name,
            policy=policy,
            description=description,
            path=path,
            tags=merged_tags,
            opts=opts,
        )

        pulumi.export(
            f"policy---{resource_name}",
            {"arn": policy_resource.arn, "policy-id": policy_resource.policy_id},
        )

        return policy

    @staticmethod
    def import_(stack: str, resource_name: str) -> iam.Policy:
        stack_ref = StackRegistry.get(stack_name=stack)
        policy = stack_ref.get_output(name=f"policy---{resource_name}")
        return iam.User.get(resource_name=resource_name, id=policy["id"])
